Changelog
=========

This document describes changes between each past release.

0.0.7 (2018-04-23)
------------------

- Fix pip install by moving away of PEP 420 Namespaces. [pcdummy]


0.0.6 (2018-04-23)
------------------

- Fix another typo in MANIFEST.in. [pcdummy]


0.0.5 (2018-04-23)
------------------

- Include python files in the pip packages, part2. [pcdummy]


0.0.4 (2018-04-23)
------------------

- Include python files in the pip packages. [pcdummy]


0.0.3 (2018-04-22)
------------------

- Add another debug line (to show CWD changes). [pcdummy]
- Add tag pushes. [pcdummy]
- Make mirroring finaly working by using "--mirror". [pcdummy]

0.0.2 (2018-04-21)
------------------

- Fixup classifiers. [pcdummy]

0.0.1 (2018-04-21)
------------------

- Initial Release. [pcdummy]